Crate time_table

Crate time_table 

Model Railroad Time Table generating program

The Time Table library is a port of the Time Table V2 program that is part of the Model Railroad System. That program is partly in C++ (low-level data structures) and part in Tcl/Tk (GUI main program). This is mostly just a port of the C++ code. This program was inspired by chapter 8 of the book How to Operate Your Model Railroad by Bruce A. Chubb. I strongly recommend reading this chapter fully before using this program. This program implements the methods described in this chapter, in an automated fashion.

The time tables this library creates are LaTeX source. You will need to install the LaTeX system to process the LaTeX source into a PDF file that can then be printed.

Modules

cab
Cab class and support types.
primio
Primitive I/O – Read functions for selected “primitive” types
station
Station and support classes.
train
The train class implements a running train and lists the stations it passes (and possibly stops at).

Structs

StationTimes
Station times class, used by the LaTeX generator methods.
TimeTableSystem
This is the main Time Table Class.

Enums

AddTrainError
ConstructorError
CreateLaTeXError
DeleteTrainError
GroupMode

Functions

StringListFromString
Convert a flat string to a list of strings.
StringListToString
Convert a list of strings to a flat string.

Type Aliases

DoubleVector
A Vector of doubles.
OptionHashMap
Option hash map, used for Print options.
StringList
List of strings.
TrainList
List of trains.
TrainStationTimes
Map of station times, indexed by train number.
TrainTimesAtStation
Map of maps of station times, indexed by station index.